@@ -6,6 +6,9 @@ class BaseModel(Model):
         conflict_fields = self.get_model_indexes()
         update_fields = self.get_excluded_fields()
 
+        if not rows:
+            return
+
         if not transaction_count:
             transaction_count = len(rows)
 
